require 'spec_helper'
describe 'rng::config', :type => :class do
  let(:title) { 'rng::config' }

  ['Ubuntu', 'RedHat', 'CentOS'].each do |distro|
    context 'with default values for all parameters' do
      if distro == 'Ubuntu'
        family = 'Debian'
        ['14.04', '16.04'].each do |release|
          if release == '14.04'
            codename = 'trusty'
          elsif release == '16.04'
            codename = 'xenial'
          end
          let(:facts) do
            {
              :osfamily                  => family,
              :operatingsystem           => distro,
              :operatingsystemmajrelease => release,
              :lsbdistcodename           => codename,
              :lsbdistid                 => distro,
              :lsbdistrelease            => release
            }
          end

          it do
            is_expected.to contain_file('/etc/default/rng-tools').with({
              'ensure' => 'file',
              'owner'  => 'root',
              'group'  => 'root',
              'mode'   => '0644',
            })

            is_expected.to contain_class('rng::install')
          end
          it { is_expected.to compile.with_all_deps }
        end
      else
        family = 'RedHat'
        release = '7'
        let(:facts) do
          {
            :osfamily                  => family,
            :operatingsystem           => distro,
            :operatingsystemmajrelease => release,
            :lsbdistid                 => distro,
            :lsbdistrelease            => release
          }
        end

        it do
            is_expected.to contain_file('/etc/sysconfig/rngd').with({
              'ensure' => 'file',
              'owner'  => 'root',
              'group'  => 'root',
              'mode'   => '0644',
            })

            is_expected.to contain_class('rng::install')
          end
        it { is_expected.to compile.with_all_deps }
      end
    end
  end
end
